@@ -65,6 +65,13 @@ CREATE TABLE Vote (
 	UNIQUE (proposition, member),
 	rating NUMERIC(2));
 
+-- Moderation Actions Log
+CREATE TABLE Moderation (
+	action_date TIMESTAMP WITH TIME ZONE
+		DEFAULT CURRENT_TIMESTAMP PRIMARY KEY,
+	moderator INT REFERENCES Member,
+	resource INT REFERENCES Resource);
+
 -- Material Items Sharing
 CREATE TABLE Item (
 	id INT PRIMARY KEY REFERENCES Resource,
@@ -79,6 +86,7 @@ CREATE TABLE Possession (
 	given_to INT REFERENCES Member);
 
 -- grant access in case we run this under another user
-GRANT ALL ON Resource, Resource_id_seq, Statement, Vote,
+GRANT INSERT, UPDATE, SELECT ON Resource, Resource_id_seq, Statement, Vote,
 	Member, Message, Item, Possession
 TO samizdat;
+GRANT INSERT, SELECT ON Moderation TO samizdat;
