@@ -48,7 +48,7 @@ USING PRESET NS},
         end
 
         page = t.table([[_('Versions'), _('Changes')]] + versions,
-            t.nav(skip + 1, "history.rb?id=#{id}&amp;"))
+            t.nav(versions.size, skip + 1, "history.rb?id=#{id}&amp;"))
 
     else   # difference engine
         old, new = old.to_i, new.to_i
