@@ -26,7 +26,10 @@ request do |session|
                 [:password, 'passwd'],
                 [:label],
                 [:submit]
-            ) + '<p><a href="member.rb">'+_('Create New Account')+'</a></p>'
+            ) + '<p><a href="member.rb">'+_('Create New Account')+'</a></p>' +
+            ( config['email'] ?
+'<p><a href="member.rb?recover">'+_('Recover Lost Password')+'</a></p>' : ''
+            )
         )
     end
 end
