@@ -186,11 +186,49 @@ end # transaction
 end
 
 request do |session|
-    set_lang, = session.params %w[set_lang]
+    set_lang, set_style, set_moderate =
+        session.params %w[set_lang set_style set_moderate]
     if set_lang then
         session.set_cookie('lang', set_lang)
         session.redirect
     end
+    if set_style then
+        session.set_cookie('style', set_style)
+        session.redirect
+    end
+    if set_moderate then
+        session.set_cookie('moderate', set_moderate,
+            config['session']['moderate_timeout'])
+        session.redirect
+    end
+
+    if session.moderator then
+        id, block, unblock = session.params %w[id block unblock]
+        if id.to_i > 0 then
+db.transaction do |db|
+            login, passwd, prefs = db.select_one(
+                'SELECT login, passwd, prefs FROM Member WHERE id = ?', id)
+            raise ResourceNotFoundError, 'Account does not exist' if login.nil?
+            raise UserError, _('Moderator accounts can not be blocked') if
+                config['site']['moderators'].include? login
+            prefs = yaml_hash(prefs)
+            db.do 'INSERT INTO Moderation (moderator, resource) VALUES (?, ?)',
+                session.id, id
+            if block and not passwd.nil? then
+                prefs['blocked_by'] = session.id
+                prefs['passwd'] = passwd   # remember password
+                db.do 'UPDATE Member SET passwd = NULL, session = NULL,
+                    prefs = ? WHERE id = ?', YAML.dump(prefs), id
+            elsif unblock and passwd.nil? and prefs['passwd'] then
+                prefs.delete('blocked_by')
+                passwd = prefs.delete('passwd')   # restore password
+                db.do 'UPDATE Member SET passwd = ?, prefs = ? WHERE id = ?',
+                    passwd, YAML.dump(prefs), id
+            end   # do nothing in unexpected situations
+end
+            session.redirect(id)
+        end
+    end
 
     confirm, = session.params %w[confirm]
     confirm and next accept_confirmation(session, confirm)
@@ -235,9 +273,22 @@ request do |session|
         [:label], [:submit, 'submit']
     )
 
-    title = session.id ? _('Change Account Settings') : _('Create New Account')
     t = session.template
+
+    style = ''
+    config['style'].each {|s, name|
+        style << %{<a href="member.rb?set_style=#{s}">#{name}</a>\n}
+    }
+    style = t.box(_('Change Theme'), style)
+
+    if config['site']['moderators'].include? session.login then
+        moderation = t.box(_('Moderation Facility'), (session.moderator ?
+            %{<a href="member.rb?set_moderate=no">} + _('Disable') + '</a>' :
+            %{<a href="member.rb?set_moderate=yes">} + _('Enable') + '</a>') )
+    end
+
+    title = session.id ? _('Change Account Settings') : _('Create New Account')
     t.page(_('Member Settings'),
         t.box(title, t.form('member.rb', *form)) +
-        t.language_box)
+        t.language_box + style + moderation.to_s)
 end
