@@ -15,11 +15,15 @@ require 'samizdat'
 
 # write message into the database, return its id
 #
-def write_message(resource, creator, title, format, content, parent, desc, edit, open)
+def write_message(resource, creator, title, format, content, parent, desc, open, action)
     content.gsub!(/\r\n/, "\n") if content
     # todo: detect duplicates
     # todo: translate into RDF assert
-    if edit then
+    if :takeover == action or :displace == action then   # moderation log
+        db.do 'INSERT INTO Moderation (moderator, resource) VALUES (?, ?)',
+            creator, parent
+    end
+    if :edit == action or :takeover == action then
         parent or raise UserError, _('Reference to previous version lost')
         # save current version at new id
         db.do 'INSERT INTO Message (version_of, creator, title, format,
@@ -44,6 +48,15 @@ def write_message(resource, creator, title, format, content, parent, desc, edit,
             id, = db.select_one "SELECT currval('Resource_id_seq')"
             File.rename(p_filename, resource.content_filename(id.to_i).untaint)
         end
+        if :takeover == action then   # disable s:openForAll
+            db.do 'UPDATE Message SET open = false WHERE id = ?', parent
+        end
+        id = parent
+    elsif :displace == action then
+        # displace content without saving previous version
+        db.do 'UPDATE Message SET creator = ?, title = ?, format = ?,
+            description = ?, content = ?, open = false WHERE id = ?',
+            creator, title, format, desc, content, parent
         id = parent
     else   # new message
         db.do 'INSERT INTO Message (creator, title, format, description,
@@ -93,18 +106,30 @@ request do |session|
 
     t = session.template
     resource = Resource.new(session)   # utility object
-    title, content, format, desc, open, parent, edit =
-        session.params %w[title content format desc open parent edit]
+    title, content, format, desc, open, parent, action =
+        session.params %w[title content format desc open parent action]
     file = session['file']   # just a file object, not its contents
     file = nil if file and 0 == file.size
 
     # input validation
     raise UserError, _('Bad input') if parent and 0 == parent.to_i
     if parent then   # don't allow to edit or reply to old versions
+        session[action] = true if
+            action and %w[reply edit takeover displace].include? action
+        action =
+            if session.has_key?('edit') then
+                :edit
+            elsif session.moderator and session.has_key?('takeover') then
+                :takeover
+            elsif session.moderator and session.has_key?('displace') then
+                :displace
+            else
+                :reply
+            end
         current, = rdf.select_one "
 SELECT ?current WHERE (dct::isVersionOf #{parent} ?current) USING PRESET NS"
-        raise UserError, sprintf(_('Use only <a href="%s">current version</a> for replies and edits'), current) if current
-        if edit then   # check if message is open for editing
+        raise UserError, sprintf(_('Use only <a href="%s">current version</a> for replies and edits'), current) if current and :displace != action
+        if :edit == action then   # check if message is open for editing
             owner, open = rdf.select_one "
 SELECT ?creator, ?open
 WHERE (dc::creator #{parent} ?creator)
@@ -114,6 +139,7 @@ USING PRESET NS"
                 owner != session.id and not open
         end
     end
+    edit = [:edit, :takeover, :displace].include? action
 
     # check description
     if desc then   # desc should refer to an existing message
@@ -181,12 +207,12 @@ USING PRESET NS"
                 format == 'text/uri-list' and not content =~ URI::ABS_URI
     end
 
-    if title and (content or file) then
+    if title and (content or file) then   # write or preview message
         if session.has_key? 'confirm' then
             id = nil   # scope fix
             db.transaction do |db|
                 id = write_message(resource, session.id, title, format,
-                    content, parent, desc, edit, open)
+                    content, parent, desc, open, action)
                 if file then
                     # todo: inject file into p2p net
                     File.rename(upload, resource.content_filename(
@@ -200,10 +226,17 @@ USING PRESET NS"
 
         else   # preview message
             content = location if file   # preview upload.ext
+            warning = '<p>'+sprintf(_('Warning: content is longer than %s characters. In some situations, it will be truncated.'), config['limit']['short'])+'</p>' if content != t.limit_string(content, config['limit']['short'])
+            desc_content = Resource.new(
+                session, desc).render(:short)[:content] if desc
             t.page( _('Message Preview'),
-                t.message(:id => 0, :date => Time::now, :creator => session.id,
+                t.message(:id => 0, :date => Time.now, :creator => session.id,
                     :full_name => session.full_name, :title => title,
-                    :format => format, :content => content, :parent => parent) +
+                    :format => format, :content => content, :parent => parent,
+                    :desc_id => desc, :desc => desc_content,
+                    :mode => :preview) +
+                warning.to_s +
+                '<p>'+_("Press 'Back' button to change the message.")+'</p>' +
                 t.form( 'message.rb',
                     [:submit, 'confirm', _('Confirm')],
                     [:hidden, 'title', title],
@@ -213,8 +246,8 @@ USING PRESET NS"
                     [:hidden, 'desc', desc],
                     [:hidden, 'open', open],
                     [:hidden, 'parent', parent],
-                    [:hidden, 'edit', edit.to_s]
-                ) + '<p>'+_("Press 'Back' button to change the message.")+'</p>'
+                    [:hidden, 'action', action.to_s]
+                )
             )
         end
 
@@ -231,7 +264,26 @@ SELECT ?content WHERE (s::content #{parent} ?content) USING PRESET NS"
             end
             # todo: message locking
         end
-        t.page(_(edit ? 'Edit Message' : 'New Message'), t.form('message.rb',
+        head =
+            case action
+            when :reply then 'Reply'
+            when :edit then 'Edit Message'
+            when :takeover then 'Take Over Message'
+            when :displace then 'Displace Message'
+            else 'New Message'
+            end
+        comment =
+            case action
+            when :reply
+                t.box(_('Parent Message'),
+                    Resource.new(session, parent).render(:short))
+            when :takeover
+                '<p><strong>' + _('Only you will be able to edit this message after takeover.') + '</strong></p>'
+            when :displace
+                '<p><strong>' + _('MESSAGE WILL BE COMPLETELY DISPLACED, NO RECOVERY WILL BE POSSIBLE. PLEASE PROVIDE DETAILED JUSTIFICATION FOR THIS ACTION.') + '</strong></p>'
+            else ''
+            end
+        t.page(_(head), t.form('message.rb',
             [:label, 'title', _('Title')], [:text, 'title', title],
             [:label, 'content', _('Content')], [:textarea, 'content', content],
             [:label, 'file', _('Upload content from file')],
@@ -246,6 +298,6 @@ SELECT ?content WHERE (s::content #{parent} ?content) USING PRESET NS"
                 [:checkbox, 'open', open, (edit ? :disabled : nil)],
             [:label], [:submit, 'preview', _('Preview')],
             [:hidden, 'parent', parent],
-            [:hidden, 'edit', edit.to_s]))
+            [:hidden, 'action', action.to_s]) + comment)
     end
 end
