@@ -70,13 +70,13 @@ USING PRESET NS}, limit_page, limit_page * skip
         head = _(head)   # translate focus names
         page = [ [ _('Focus') + ' / ' + head + ' / ' + _('Recent Updates') +
                 (skip > 0? sprintf(_(', page %s'), skip + 1) : ''),
-            t.list(resources,
-                t.nav(skip + 1, "resource.rb?id=#{id}&amp;", 'skip_related'))
+            t.list( resources, t.nav(resources.size, skip + 1,
+                "resource.rb?id=#{id}&amp;", 'skip_related') )
         ] ]
     else page = []
     end
 
     session.options['x-pingback'] = session.base + 'pingback.rb' if
-        config['pingback']['login']
+        config['pingback'].kind_of?(Hash) and config['pingback']['login']
     t.page(title, page << [ title, desc ])
 end
