@@ -7,7 +7,7 @@
 #   the GNU General Public License version 2 or later.
 #
 
-SAMIZDAT_VERSION = '0.5.3'
+SAMIZDAT_VERSION = '0.5.4'
 
 # :main:samizdat.rb
 
@@ -27,6 +27,7 @@ rescue LoadError
     end
 end
 
+require 'jcode'   # multi-byte character support
 require 'stringio'   # fix a conflict between Ruby 1.6 cgi.rb and yaml.rb
 require 'tempfile'
 
@@ -75,6 +76,7 @@ def digest(value)
     Digest::MD5.new(value).hexdigest
 end
 
+require 'yaml'
 require 'singleton'
 
 # load and cache site configuration from config.yaml
@@ -83,7 +85,6 @@ class SamizdatConfig
     include Singleton
 
     def initialize
-        require 'yaml'
         @config = File.open('config.yaml') {|f| YAML.load(f) }
     end
 
@@ -96,6 +97,12 @@ def config
     SamizdatConfig.instance.config
 end
 
+# parse YAML data or return empty hash
+#
+def yaml_hash(yaml)
+    YAML.load(yaml.to_s) or {}
+end
+
 # shortcut for page length limit config option
 #
 def limit_page
