@@ -29,7 +29,7 @@ class Focus < Resource
 
         if @id.kind_of? Integer then
             begin
-                @name = render(:short)[:head]   # watch out for recursion!
+                @name = render(:title)   # watch out for recursion!
             rescue ResourceNotFoundError   # bad id in focus cookie
                 session.set_cookie('focus', nil, 0)   # delete bad cookie
                 session.redirect(session.base)
