@@ -23,9 +23,11 @@ class Resource
 
     # in :list mode (default) return rendered desc
     #
+    # in :title mode return resource title
+    #
     # in :short mode return hash with :type, :head, and :desc keys
     #
-    # in :full mode, add :related resources and :focuses to the hash
+    # in :full mode, add :messages and :focuses to the hash
     # (only one full resource per page is possible)
     #
     def render(mode=:list)
@@ -61,16 +63,45 @@ class Resource
                 end
             r[:type] = label
         end
+        r[:head] = CGI.escapeHTML(template.limit_string(r[:head]))
+        return r[:head] if :title == mode
         return template.resource(id, r[:head], r[:desc]) if :list == mode
         r[:focuses] = render_focuses(r[:head], mode) if :full == mode
         class << r
             def to_s
-                [ self[:desc], self[:focuses], self[:related] ].join
+                [ self[:desc], self[:focuses], self[:messages] ].join
             end
         end
         r
     end
 
+    # render the most recent related resource in :short mode and a list of less
+    # recent related resources in :title mode
+    #
+    def render_related
+        resources = rdf.select_all( %{
+SELECT ?resource
+WHERE (rdf::subject ?stmt ?resource)
+      (rdf::predicate ?stmt dc::relation)
+      (rdf::object ?stmt #{id})
+      (s::inReplyTo ?resource ?parent)
+      (dct::isVersionOf ?resource ?current)
+      (s::rating ?stmt ?rating)
+      (dc::date ?resource ?date)
+LITERAL ?rating > 0 AND ?parent IS NULL AND ?current IS NULL
+ORDER BY ?date DESC
+USING PRESET NS}, limit_page)
+        related = Resource.new(session,resources.shift[0]).render(:short)[:desc]
+        related += _('Also related to this focus: ') +
+            resources.collect {|resource,|
+                template.resource_href(resource,
+                    Resource.new(session, resource).render(:title))
+            }.join(', ') if resources.size > 0
+        related = template.box(_('Recent updates in focus: ') +
+            template.resource_href(id, render(:title)), related)
+        related
+    end
+
     # multimedia message content location
     #
     # if _format_ or _login_ are not specified, this Resource object should be
@@ -143,11 +174,34 @@ LITERAL ?current IS NULL
 ORDER BY ?date DESC
 USING PRESET NS}, limit_page, limit_page * skip
             ).collect {|msg,| Resource.new(session, msg).render }
+            r[:desc] = '<p>' + r[:desc] + '</p>'
+            # check if account is blocked
+            passwd, prefs = db.select_one(
+                'SELECT passwd, prefs FROM Member WHERE id = ?', id)
+            if passwd.nil? then   # account is blocked
+                blocked_by = yaml_hash(prefs)['blocked_by'].to_i
+                if blocked_by > 0 then
+                    b_name, = db.select_one(
+                        'SELECT full_name FROM Member WHERE id = ?', blocked_by)
+                    r[:desc] += '<p>' + sprintf(
+                        _('Account blocked by moderator: %s.'),
+                        template.resource_href(blocked_by,
+                            CGI.escapeHTML(b_name))) + '</p>'
+                end
+            end
+            if session.moderator and   # show block/unblock button
+            not config['site']['moderators'].include? login then
+                r[:desc] += template.form('member.rb', 
+                    passwd.nil? ?
+                        [:submit_moderator, 'unblock', _('UNBLOCK')] :
+                        [:submit_moderator, 'block', _('BLOCK')],
+                    [:hidden, 'id', id])
+            end
             r[:desc] = template.box(nil, r[:desc])
-            r[:related] = template.box( _('Latest Messages') +
+            r[:messages] = template.box( _('Latest Messages') +
                 (skip > 0? sprintf(_(', page %s'), skip + 1) : ''),
-                template.list(messages,
-                    template.nav(skip + 1, %{resource.rb?id=#{id}&amp;}))
+                template.list( messages, template.nav(messages.size,
+                    skip + 1, %{resource.rb?id=#{id}&amp;}) )
             ) if messages.size > 0
         end
         r
@@ -162,13 +216,16 @@ WHERE (dc::date #{id} ?date)
       (s::fullName ?creator ?name)
       (s::login ?creator ?login)
 USING PRESET NS}
+        return { :head => head } if :title == mode
         replies, = rdf.select_one "
 SELECT count(?msg) WHERE (s::inReplyTo ?msg #{id}) USING PRESET NS"
         focus = render_focuses(head, mode) unless :full == mode or
             Focus == self.class   # avoid recursion
-        return { :head => head, :desc => template.message_info(
-            :id => id, :date => date, :creator => creator, :full_name => name,
-            :focus => focus, :replies => replies) } if :list == mode
+        return { :head => head,
+            :desc => template.message_info(
+                :id => id, :date => date, :creator => creator,
+                :full_name => name, :focus => focus, :replies => replies)
+        } if :list == mode
         # extra data for :short and :full modes
         desc_id, = rdf.select_one "
 SELECT ?desc WHERE (dc::description #{id} ?desc) USING PRESET NS"
@@ -180,6 +237,8 @@ SELECT ?format WHERE (dc::format #{id} ?format) USING PRESET NS"
 SELECT ?content WHERE (s::content #{id} ?content) USING PRESET NS"
         content = content_location(id, format, login) if content.nil? and
             format and not config['format']['inline'].include? format
+        content = template.limit_string(content, config['limit']['short']) if
+            :short == mode
         if mode == :full then   # show parent and versions only in full mode
             current, = rdf.select_one "
 SELECT ?current WHERE (dct::isVersionOf #{id} ?current) USING PRESET NS"
@@ -197,6 +256,7 @@ SELECT ?open WHERE (s::openForAll #{id} ?open) USING PRESET NS"
             end
         end
         r = { :head => head }
+        # :content is special to description messages
         r[:content] = template.message_content(:title => head,
             :content => content, :format => format, :mode => mode)
         r[:desc] = template.message(:id => id, :date => date,
@@ -215,11 +275,11 @@ WHERE (dc::date ?msg ?date)
 ORDER BY ?date
 USING PRESET NS}, limit_page, limit_page * skip
             ).collect {|msg,| Resource.new(session, msg).render(:short)[:desc] }
-            r[:related] = template.box(
+            r[:messages] = template.box(
                 _('Replies') +
                     (skip > 0? sprintf(_(', page %s'), skip + 1) : ''),
-                template.list(replies,
-                    template.nav(skip + 1, %{resource.rb?id=#{id}&amp;})),
+                template.list( replies, template.nav(replies.size, skip + 1,
+                    %{resource.rb?id=#{id}&amp;}) ),
                 'replies'
             ) if replies.size > 0
             # navigation links
@@ -231,6 +291,7 @@ USING PRESET NS}, limit_page, limit_page * skip
 
     def render_statement(mode)
         r = { :head => _('Statement') + ' ' + id.to_s }
+        return r if :title == mode
         stmt = rdf.select_one %{
 SELECT ?p, ?s, ?o
 WHERE (rdf::predicate #{id} ?p)
@@ -253,6 +314,7 @@ USING rdf FOR #{ns['rdf']}}
 
     def render_vote(mode)
         r = { :head => _('Vote') + ' ' + id.to_s }
+        return r if :title == mode
         date, stmt, member, name, rating = rdf.select_one "
 SELECT ?date, ?stmt, ?member, ?name, ?rating
 WHERE (dc::date #{id} ?date)
