@@ -105,7 +105,7 @@ class Session < SimpleDelegator
 db.transaction do |db|
             @id, @login, @full_name, @email, login_time = db.select_one 'SELECT id, login, full_name, email, login_time FROM Member WHERE session = ?', @session
             if @id then
-                if login_time and login_time.to_time < Time::now - @@login_timeout then
+                if login_time and login_time.to_time < Time.now - @@login_timeout then
                     close   # stale session
                 else
                     # uncomment to regenerate session on each access:
@@ -113,6 +113,8 @@ db.transaction do |db|
                     #db.do "UPDATE Member SET last_time = 'now', session = ?
                     #WHERE id = ?", @session, @id
                     set_cookie('session', @session, @@last_timeout)
+                    @moderator = ('yes' == cookie('moderate') and
+                        config['site']['moderators'].include? @login)
                 end
             end
 end
@@ -131,6 +133,9 @@ end
 
     attr_reader :id, :login, :full_name, :email
 
+    # true if moderator priviledges are enabled
+    attr_reader :moderator
+
     # open new session on login
     #
     # redirect to referer on success
@@ -173,7 +178,7 @@ end
     def prefs(login=@login)
         return @prefs unless @prefs.nil?
         prefs, = db.select_one 'SELECT prefs FROM Member WHERE login = ?', login
-        @prefs = (YAML::load(prefs.to_s) or {})
+        @prefs = yaml_hash(prefs)
     end
 
     # save updated member preferences to database
@@ -183,7 +188,7 @@ end
     def save_prefs(login=@login, confirm=nil)
         @prefs or raise RuntimeError, _('No preferences to save')
         db.do 'UPDATE Member SET prefs = ?, confirm = ? WHERE login = ?',
-            YAML::dump(@prefs), confirm, login
+            YAML.dump(@prefs), confirm, login
     end
 
     # return list of values of CGI parameters, tranform empty values to nils
@@ -265,6 +270,6 @@ end
 private
 
     def generate_session
-        digest(@id.to_s + Time::now.to_s)
+        digest(@id.to_s + Time.now.to_s)
     end
 end
