@@ -29,8 +29,9 @@ class Database
         # todo: verify concurrency in db and storage
         # optimize: generate connection pool
         require 'dbi'
-        @db = DBI.connect('DBI:Pg:samizdat',
-            ENV['USER']? ENV['USER'] : 'samizdat')
+        @db = DBI.connect(config['db']['dsn'],
+            (ENV['USER'] or config['db']['user']),
+            ENV['USER']? nil : config['db']['passwd'])
         @db["AutoCommit"] = false
     end
 
@@ -482,7 +483,7 @@ class SquishQuery
                 if c[i][2].nil? then   # new alias
                     c[i][2] = ac.dup
                     table[ac] = c[i][0][0]
-                    ac.succ!
+                    ac.next!
                 end
             end
         end   # optimize: unnecessary aliases are generated
@@ -514,7 +515,7 @@ class SquishQuery
                         ac+'.literal = false AND '+
                         ac+'.uriref = true AND '+
                         ac+".label = '"+node+"'"
-                    ac.succ!
+                    ac.next!
                 end
                 ground = true
             end
