@@ -31,16 +31,22 @@ class Template
     # HTML header, title, and style settings
     #
     def head(title='')
+        style = @session.cookie('style')
+        style = 'default' unless config['style'].keys.include?(style)
+        css = %{\n    <link rel="stylesheet" type="text/css" href="css/#{style}.css" media="screen" />\n}
+        config['style'].each do |s, t|
+            css << %{    <link rel="alternate stylesheet" type="text/css" title="#{t}" href="css/#{s}.css" media="screen" />\n} if
+                s != style
+        end
         @link[:pingback] = @session.options['x-pingback'] if
             @session.options['x-pingback']
 %{<?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
-    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
+    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
 <head>
     <title>#{title}</title>
-    <meta name="generator" content="Samizdat #{SAMIZDAT_VERSION}"/>
-    <link rel="stylesheet" type="text/css" href="css/default.css" media="screen"/>} +
+    <meta name="generator" content="Samizdat #{SAMIZDAT_VERSION}" />#{css}} +
         @link.to_a.collect {|rel, href|
             %{\n    <link rel="#{rel}" href="#{href}" />}
         }.join + %{
@@ -58,12 +64,13 @@ class Template
     #
     def site_head
         # todo: replace head-left with site logo
-%{<a href="#main" style="display:none;">Skip navigation</a>
+%{<div><a href="#main" style="display:none;">Skip navigation</a></div>
 <div id="head">
     <div id="head-left"><a href="#{@session.base}" title="#{config['site']['name']}">#{config['site']['logo']}</a></div>
     <div id="head-right"><a href="message.rb">}+_('Publish')+%{</a>
         :: <a href="item.rb">}+_('Share')+%{</a>
-        :: <a href="query.rb">}+_('Search')+%{</a></div>
+        :: <a href="query.rb">}+_('Search')+%{</a>
+        :: <a href="#{config['site']['about']}">}+_('About')+%{</a></div>
 </div>
 <div id="subhead">
     <div id="subhead-right">#{member_line}</div>
@@ -89,8 +96,8 @@ software; you can distribute/modify it under the terms of the GNU
     def member_line
         settings = %{<a href="member.rb">#{_('Settings')}</a>, }
         if @session.id then
-            resource_href(@session.id, @session.full_name) + ': ' +
-                settings + %{<a href="logout.rb">#{_('Log out')}</a>}
+            resource_href(@session.id, CGI.escapeHTML(@session.full_name)) +
+                ': ' + settings + %{<a href="logout.rb">#{_('Log out')}</a>}
         else
             settings + %{<a href="login.rb">#{_('Log in')}</a>}
         end
@@ -118,10 +125,25 @@ software; you can distribute/modify it under the terms of the GNU
 </div>\n}
     end
 
+    # return _string_ truncated to the _limit_, with ellipsis if necessary
+    #
+    def limit_string(string, limit=config['limit']['title'])
+        $KCODE = 'utf8'
+        if string.jsize > limit then
+            string.each_char[0, limit - 1].join + '…'
+        else
+            string
+        end
+    end
+
     # navigation link to a given page number
     #
-    def nav(skip, script=File.basename(@session.script_name)+'?', name='skip')
-%{<div class="nav"><a href="#{script}#{name}=#{skip}">}+_('next page')+%{</a></div>\n}
+    def nav(size, skip, script=File.basename(@session.script_name)+'?', name='skip')
+        # todo: reorganize
+        return '' if true == size or
+            (size.kind_of?(Numeric) and size < limit_page)
+        %{<div class="nav"><a href="#{script}#{name}=#{skip}">} +
+            _('next page') + %{</a></div>\n}
     end
 
     # resource list with navigation link
@@ -132,8 +154,7 @@ software; you can distribute/modify it under the terms of the GNU
         list.collect {|li|
             even = 1 - even
             %{<li#{' class="even"' if even == 1}>#{li}</li>\n}
-        }.join + %{</ul>\n<div class="foot">\n} +
-        foot + ((list.size < limit_page)? '' : nav) + %{</div>\n}
+        }.join + %{</ul>\n<div class="foot">\n} + foot + nav + %{</div>\n}
     end
 
     # resource table with navigation link
@@ -149,8 +170,7 @@ software; you can distribute/modify it under the terms of the GNU
                 "<td>#{td or '&nbsp;'}</td>\n"
             }.join + "</tr>\n"
         }.join +
-        %{</tbody></table>\n<div class="foot">\n} +
-        foot + ((table.size < limit_page)? '' : nav) + %{</div>\n}
+        %{</tbody></table>\n<div class="foot">\n} + foot + nav + %{</div>\n}
     end
 
     # type can be any of the following:
@@ -165,7 +185,7 @@ software; you can distribute/modify it under the terms of the GNU
     def form_field(type, name=nil, value=nil, default=nil)
         value = CGI.escapeHTML(value) if value.class == String
         name = %{ name="#{name}"} if name
-        name += ' disabled=""' if name and :disabled == default
+        name += ' disabled="disabled"' if name and :disabled == default
         case type
         when :label   # todo: generate field idref for label for attribute
 %{<div class="label"><label>#{value}</label></div>\n}
@@ -177,15 +197,15 @@ software; you can distribute/modify it under the terms of the GNU
     selected = (v == default)? ' selected="selected"' : ''
     %{    <option#{selected} value="#{v}">#{l}</option>\n}
 }.join + "</select>\n"
-        when :submit
+        when :submit, :submit_moderator
             value = _('Submit') if value.nil?
-%{<input#{name} type="submit" value="#{value}" class="submit"/>\n}
+%{<input#{name} type="submit" value="#{value}" class="#{type}" />\n}
         else
             if :checkbox == type then
                 name += ' checked=""' if value
                 value = 'true'
             end
-%{<input#{name} type="#{type}" value="#{value}"/>\n}
+%{<input#{name} type="#{type}" value="#{value}" />\n}
         end
     end
 
@@ -263,7 +283,7 @@ software; you can distribute/modify it under the terms of the GNU
     # render link to resource with a tooltip
     #
     def resource_href(id, title)
-        %{<a title="#{_('Click to view the resource')}" href="#{id}">#{CGI.escapeHTML(title.to_s)}</a>}
+%{<a title="#{_('Click to view the resource')}" href="#{id}">#{limit_string(title)}</a>}
     end
 
     # render resource description for resource listing
@@ -309,20 +329,24 @@ software; you can distribute/modify it under the terms of the GNU
             '<p>' + content.split("\n").collect {|line|
                 case line
                 when /\A#\s*(.*?)\z/
-                    CGI.escapeHTML($1) + '<br/>'
+                    CGI.escapeHTML($1) + '<br />'
                 when URI::URI_REF
                     line = CGI.escapeHTML(line)
-                    %{<a href="#{line}">#{line}</a><br/>}
+                    %{<a href="#{line}">#{line}</a><br />}
                 end
             }.join + '</p>'
         when 'application/x-textile'   # textile formatted text
-            RedCloth.new(content).to_html   # todo: filter_html
+            begin
+                RedCloth.new(content).to_html   # todo: filter_html
+            rescue Exception
+                raise RuntimeError, $!.message
+            end
         when 'application/x-squish'   # inline query form
             form('query.rb',
                 [:textarea, 'query', content], [:label],
                 [:submit, 'run', _('Run')])
         when /^image\//   # <img/> reference
-            %{<img alt="#{CGI.escapeHTML(params[:title].to_s)}" src="#{content}"/>}
+            %{<img alt="#{CGI.escapeHTML(params[:title].to_s)}" src="#{content}" />}
         else   # <a/> reference
             %{<p><a href="#{content}">} +
                 sprintf(_('%s content'), params[:format]) + '</a></p>'
@@ -334,25 +358,41 @@ software; you can distribute/modify it under the terms of the GNU
     # _params_ is a Hash with keys :id, :date, :creator, :full_name, :focus,
     # :title, :format, :content, :parent, :desc_id, :desc, :mode
     #
+    # _:mode_ can be :short, :full, or :preview
+    #
     def message(params) 
         info = message_info(params)
         content = message_content(params)
         params[:desc] and content =
-            case params[:mode]
-            when :full
-                box(resource_href(params[:desc_id], _('Description')),
-                    params[:desc], 'desc') + content
-            when :short
+            if :short == params[:mode] then
                 params[:desc] + %{<p><a href="#{params[:id]}">} +
                     _('See the full message') + '</a></p>'
+            else
+                box(resource_href(params[:desc_id], _('Description')),
+                    params[:desc], 'desc') + content
             end
-        buttons = %{<div class="foot">\n} + form( 'message.rb',
-            [:hidden, 'title', params[:title]],
-            [:hidden, 'parent', params[:id]],
-            [:submit, 'reply', _('Reply')],
-            [:submit, 'edit', _('Edit'), (params[:open]? nil : :disabled )]
-        ) + %{</div>\n} if :full == params[:mode] and not params[:current]
-%{<div class="message" id="#{params[:id]}">
+        if :full == params[:mode] then   # buttons
+            if not params[:current] then   # no buttons for old versions
+                buttons = [ 
+                    [:submit, 'reply', _('Reply')],
+                    [:submit, 'edit', _('Edit'),
+                        (params[:open]? nil : :disabled )]
+                ]
+                @session.moderator and buttons.push(
+                    [:submit_moderator, 'takeover', _('TAKE OVER')],
+                    [:submit_moderator, 'displace', _('DISPLACE')])
+            elsif @session.moderator then   # old versions can be displaced
+                buttons = [
+                    [:submit_moderator, 'displace', _('DISPLACE')]
+                ]
+            end
+            buttons and buttons = %{<div class="foot">\n} +
+                form('message.rb',
+                    [:hidden, 'title', params[:title]],
+                    [:hidden, 'parent', params[:id]],
+                *buttons) + %{</div>\n}
+        end
+%{<div class="message" id="id#{params[:id]}">
 <div class="title">#{resource_href(params[:id], params[:title])}</div>
 <div class="info">#{info}</div>
 <div class="content">#{content}</div>
@@ -366,13 +406,16 @@ software; you can distribute/modify it under the terms of the GNU
         return '' unless defined?(GetText)
         old_language = @session.language
         list = ''
-        config['locale']['languages'].each do |lang|
+        config['locale']['languages'].sort.each do |lang|
             lang.untaint
             @session.language = lang
-            list += %{<a href="member.rb?set_lang=#{lang}">} +
-                _('English') + "</a>\n"
+            name = _('English')
+            @session.language = old_language
+            next if 'English' == name and 'en' != lang   # broken localization
+            name += _(' (default language)') if
+                lang == config['locale']['languages'][0]
+            list += %{<a href="member.rb?set_lang=#{lang}">#{name}</a>\n}
         end
-        @session.language = old_language
         box(_('Change Interface Language'), list)
     end
 
@@ -446,7 +489,7 @@ software; you can distribute/modify it under the terms of the GNU
         [old, new].collect {|msg| "<th>#{msg[:info]}</th>\n" }.join +
         %{</tr></thead>\n<tbody>\n} +
         diff_calculate(old[:content], new[:content]).collect {|left, right|
-            width = right ? ' width="50%"' : ' colspan="2"'
+            width = right ? ' style="width: 50%"' : ' colspan="2"'
             left = {:format => old[:format], :content => left,
                 :class => (right ? ' class="delete"' : '')} if left
             right = {:format => new[:format], :content => right,
@@ -459,13 +502,20 @@ software; you can distribute/modify it under the terms of the GNU
 
     # wrap page title and body with heads and foots
     #
-    # body can be String or Array of pairs [title, body]; in latter case, title
-    # can be defaulted to the title of the first pair
+    # _body_ can be String or Array of pairs [title, body]; in latter case,
+    # _title_ can be defaulted to the title of the first pair
     #
-    def page(title, body)
-        body = [[title, body]] unless body.class == Array
-        title = body[0][0] if title.nil?
-        main = body.collect {|t, b| box(CGI.escapeHTML(t.to_s), b) }.join
+    # if _options_ includes :no_box flag, body isn't wrapped in box
+    #
+    def page(title, body, options={})
+        main =
+            if title and options[:no_box] then
+                body
+            else
+                body = [[title, body]] unless body.class == Array
+                title = body[0][0] if title.nil?
+                body.collect {|t, b, id| box(t, b, id) }.join
+            end
         head(config['site']['name'] + ': ' + title.to_s) + site_head() +
             %{\n<div id="main">\n} + main + main_foot + "\n</div>\n" + foot
     end
