@@ -28,7 +28,7 @@ class TC_Robot < Test::Unit::TestCase
         @base = URI.parse('http://localhost' + config['site']['base'] + '/')
         @login = 'test' + STAMP
         @full_name = 'Test' + STAMP
-        @email = 'test@localhost'
+        @email = 'test' + STAMP + '@localhost'
         @passwd = 'test'
     end
 
@@ -64,7 +64,7 @@ class TC_Robot < Test::Unit::TestCase
         assert_equal SAMIZDAT_VERSION, version
         # look for login form
         assert_equal 'login.rb',
-            root.elements['/html/body/div[@id="subhead"]/div/a'
+            root.elements['/html/body/div[@id="subhead"]/div/a[2]'
             ].attributes['href']
 
         # test anonymous check on publish
