@@ -12,22 +12,7 @@
 require 'test/unit'
 require 'samizdat'
 
-class TestSession
-    def base
-        'http://localhost/' + config['site']['base'] + '/'
-    end
-end
-
 class TC_Storage < Test::Unit::TestCase
-    def setup
-        @session = TestSession.new
-        @rdf = SamizdatRDF.new(@session.base)
-    end
-
-    def teardown
-        @rdf, @session = nil
-    end
-
     def test_query_select
         # initialize
         query_text = %{
@@ -44,7 +29,7 @@ LITERAL ?rating >= -1
 ORDER BY ?rating DESC
 USING PRESET NS}
         begin
-            query = SquishQuery.new(@rdf, query_text)
+            query = SquishQuery.new(query_text)
         rescue
             assert false, "SquishQuery initialization raised #{$!.class}: #{$!}"
         end
@@ -67,12 +52,12 @@ USING PRESET NS}
 
         # query result
         begin
-            sql1 = @rdf.select(query)
+            sql1 = rdf.select(query)
         rescue
             assert false, "select with pre-parsed query raised #{$!.class}: #{$!}"
         end
         begin
-            sql2 = @rdf.select(query_text)
+            sql2 = rdf.select(query_text)
         rescue
             assert false, "select with query text raised #{$!.class}: #{$!}"
         end
@@ -84,15 +69,13 @@ USING PRESET NS}
         query_text = %{
 INSERT ?msg
 UPDATE ?title = 'Test Message', ?content = 'Some text.'
-WHERE (dc::creator ?msg base::1)
+WHERE (dc::creator ?msg 1)
       (dc::title ?msg ?title)
       (s::content ?msg ?content)
-      (s::thread ?msg ?msg)
 USING dc FOR #{ns['dc']}
-      s FOR #{ns['s']}
-      base FOR #{@session.base}}
+      s FOR #{ns['s']}}
         begin
-            query = SquishQuery.new(@rdf, query_text)
+            query = SquishQuery.new(query_text)
         rescue
             assert false, "SquishQuery initialization raised #{$!.class}: #{$!}"
         end
@@ -109,7 +92,7 @@ USING dc FOR #{ns['dc']}
 
         # transform_pattern
         assert_equal config['map']['dc::creator'], Hash[*query.c[0][1]]
-        assert_equal [[0, 1]], query.pm["#{@session.base}1"]
+        assert_equal [[0, 1]], query.pm["1"]
         # todo: check jc
         assert query.b.include?('?title')
 
@@ -123,7 +106,7 @@ SELECT ?msg
 WHERE (s::inReplyTo ?msg ?parent)
 USING s FOR #{ns['s']}}
         begin
-            query = SquishQuery.new(@rdf, query_text)
+            query = SquishQuery.new(query_text)
         rescue
             assert false, "SquishQuery initialization raised #{$!.class}: #{$!}"
         end
@@ -143,12 +126,12 @@ USING s FOR #{ns['s']}}
 
         # query result
         begin
-            sql1 = @rdf.select(query)
+            sql1 = rdf.select(query)
         rescue
             assert false, "select with pre-parsed query raised #{$!.class}: #{$!}"
         end
         begin
-            sql2 = @rdf.select(query_text)
+            sql2 = rdf.select(query_text)
         rescue
             assert false, "select with query text raised #{$!.class}: #{$!}"
         end
