@@ -24,7 +24,11 @@ class TestSession
         bindtextdomain('samizdat', nil, 'C', 'utf-8')
     end
 
-    attr_accessor :id, :login, :full_name, :options, :base
+    def cookie(name)
+        nil
+    end
+
+    attr_accessor :id, :login, :full_name, :options, :base, :moderator
 end
 
 class TC_Template < Test::Unit::TestCase
